/**
 * Copyright (c) 2000-2012 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.martico.service.persistence;

import com.liferay.portal.service.persistence.BasePersistence;

import com.martico.model.ActivityObjective;

/**
 * The persistence interface for the activity objective service.
 *
 * <p>
 * Caching information and settings can be found in <code>portal.properties</code>
 * </p>
 *
 * @author edusaldana
 * @see ActivityObjectivePersistenceImpl
 * @see ActivityObjectiveUtil
 * @generated
 */
public interface ActivityObjectivePersistence extends BasePersistence<ActivityObjective> {
	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this interface directly. Always use {@link ActivityObjectiveUtil} to access the activity objective persistence. Modify <code>service.xml</code> and rerun ServiceBuilder to regenerate this interface.
	 */

	/**
	* Caches the activity objective in the entity cache if it is enabled.
	*
	* @param activityObjective the activity objective
	*/
	public void cacheResult(
		com.martico.model.ActivityObjective activityObjective);

	/**
	* Caches the activity objectives in the entity cache if it is enabled.
	*
	* @param activityObjectives the activity objectives
	*/
	public void cacheResult(
		java.util.List<com.martico.model.ActivityObjective> activityObjectives);

	/**
	* Creates a new activity objective with the primary key. Does not add the activity objective to the database.
	*
	* @param activityObjectiveId the primary key for the new activity objective
	* @return the new activity objective
	*/
	public com.martico.model.ActivityObjective create(long activityObjectiveId);

	/**
	* Removes the activity objective with the primary key from the database. Also notifies the appropriate model listeners.
	*
	* @param activityObjectiveId the primary key of the activity objective
	* @return the activity objective that was removed
	* @throws com.martico.NoSuchActivityObjectiveException if a activity objective with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public com.martico.model.ActivityObjective remove(long activityObjectiveId)
		throws com.liferay.portal.kernel.exception.SystemException,
			com.martico.NoSuchActivityObjectiveException;

	public com.martico.model.ActivityObjective updateImpl(
		com.martico.model.ActivityObjective activityObjective, boolean merge)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the activity objective with the primary key or throws a {@link com.martico.NoSuchActivityObjectiveException} if it could not be found.
	*
	* @param activityObjectiveId the primary key of the activity objective
	* @return the activity objective
	* @throws com.martico.NoSuchActivityObjectiveException if a activity objective with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public com.martico.model.ActivityObjective findByPrimaryKey(
		long activityObjectiveId)
		throws com.liferay.portal.kernel.exception.SystemException,
			com.martico.NoSuchActivityObjectiveException;

	/**
	* Returns the activity objective with the primary key or returns <code>null</code> if it could not be found.
	*
	* @param activityObjectiveId the primary key of the activity objective
	* @return the activity objective, or <code>null</code> if a activity objective with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public com.martico.model.ActivityObjective fetchByPrimaryKey(
		long activityObjectiveId)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns all the activity objectives where activityId = &#63;.
	*
	* @param activityId the activity ID
	* @return the matching activity objectives
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<com.martico.model.ActivityObjective> findByActivity(
		long activityId)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns a range of all the activity objectives where activityId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	* </p>
	*
	* @param activityId the activity ID
	* @param start the lower bound of the range of activity objectives
	* @param end the upper bound of the range of activity objectives (not inclusive)
	* @return the range of matching activity objectives
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<com.martico.model.ActivityObjective> findByActivity(
		long activityId, int start, int end)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns an ordered range of all the activity objectives where activityId = &#63;.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	* </p>
	*
	* @param activityId the activity ID
	* @param start the lower bound of the range of activity objectives
	* @param end the upper bound of the range of activity objectives (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of matching activity objectives
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<com.martico.model.ActivityObjective> findByActivity(
		long activityId, int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the first activity objective in the ordered set where activityId = &#63;.
	*
	* @param activityId the activity ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching activity objective
	* @throws com.martico.NoSuchActivityObjectiveException if a matching activity objective could not be found
	* @throws SystemException if a system exception occurred
	*/
	public com.martico.model.ActivityObjective findByActivity_First(
		long activityId,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException,
			com.martico.NoSuchActivityObjectiveException;

	/**
	* Returns the first activity objective in the ordered set where activityId = &#63;.
	*
	* @param activityId the activity ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the first matching activity objective, or <code>null</code> if a matching activity objective could not be found
	* @throws SystemException if a system exception occurred
	*/
	public com.martico.model.ActivityObjective fetchByActivity_First(
		long activityId,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the last activity objective in the ordered set where activityId = &#63;.
	*
	* @param activityId the activity ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching activity objective
	* @throws com.martico.NoSuchActivityObjectiveException if a matching activity objective could not be found
	* @throws SystemException if a system exception occurred
	*/
	public com.martico.model.ActivityObjective findByActivity_Last(
		long activityId,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException,
			com.martico.NoSuchActivityObjectiveException;

	/**
	* Returns the last activity objective in the ordered set where activityId = &#63;.
	*
	* @param activityId the activity ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the last matching activity objective, or <code>null</code> if a matching activity objective could not be found
	* @throws SystemException if a system exception occurred
	*/
	public com.martico.model.ActivityObjective fetchByActivity_Last(
		long activityId,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the activity objectives before and after the current activity objective in the ordered set where activityId = &#63;.
	*
	* @param activityObjectiveId the primary key of the current activity objective
	* @param activityId the activity ID
	* @param orderByComparator the comparator to order the set by (optionally <code>null</code>)
	* @return the previous, current, and next activity objective
	* @throws com.martico.NoSuchActivityObjectiveException if a activity objective with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public com.martico.model.ActivityObjective[] findByActivity_PrevAndNext(
		long activityObjectiveId, long activityId,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException,
			com.martico.NoSuchActivityObjectiveException;

	/**
	* Returns all the activity objectives.
	*
	* @return the activity objectives
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<com.martico.model.ActivityObjective> findAll()
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns a range of all the activity objectives.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	* </p>
	*
	* @param start the lower bound of the range of activity objectives
	* @param end the upper bound of the range of activity objectives (not inclusive)
	* @return the range of activity objectives
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<com.martico.model.ActivityObjective> findAll(
		int start, int end)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns an ordered range of all the activity objectives.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	* </p>
	*
	* @param start the lower bound of the range of activity objectives
	* @param end the upper bound of the range of activity objectives (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of activity objectives
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<com.martico.model.ActivityObjective> findAll(
		int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Removes all the activity objectives where activityId = &#63; from the database.
	*
	* @param activityId the activity ID
	* @throws SystemException if a system exception occurred
	*/
	public void removeByActivity(long activityId)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Removes all the activity objectives from the database.
	*
	* @throws SystemException if a system exception occurred
	*/
	public void removeAll()
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the number of activity objectives where activityId = &#63;.
	*
	* @param activityId the activity ID
	* @return the number of matching activity objectives
	* @throws SystemException if a system exception occurred
	*/
	public int countByActivity(long activityId)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Returns the number of activity objectives.
	*
	* @return the number of activity objectives
	* @throws SystemException if a system exception occurred
	*/
	public int countAll()
		throws com.liferay.portal.kernel.exception.SystemException;
}