package com.martico.portlet.activity;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletURL;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import javax.portlet.ResourceRequest;
import javax.portlet.ResourceResponse;
import javax.portlet.ResourceURL;

import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.portlet.ModelAndView;
import org.springframework.web.portlet.bind.annotation.ActionMapping;
import org.springframework.web.portlet.bind.annotation.RenderMapping;
import org.springframework.web.portlet.bind.annotation.ResourceMapping;
import org.springframework.web.portlet.mvc.AbstractController;

import com.liferay.portal.kernel.dao.orm.QueryUtil;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.servlet.SessionErrors;
import com.liferay.portal.kernel.servlet.SessionMessages;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.service.ServiceContext;
import com.liferay.portal.service.ServiceContextFactory;
import com.liferay.portlet.asset.model.AssetCategory;
import com.liferay.portlet.asset.model.AssetVocabulary;
import com.liferay.portlet.asset.service.AssetCategoryLocalServiceUtil;
import com.liferay.portlet.asset.service.AssetVocabularyLocalServiceUtil;
import com.martico.model.Activity;
import com.martico.portlet.activity.export.ActivityPdfWriter;
import com.martico.portlet.activity.form.ActivityForm;
import com.martico.portlet.activity.search.ActivitySearchContainer;
import com.martico.portlet.activity.search.ActivitySearchDisplayTerms;
import com.martico.portlet.activity.util.ActivityUtil;
import com.martico.portlet.util.ArrayUtils;
import com.martico.portlet.util.AssetCategoryComparator;
import com.martico.service.ActivityLocalServiceUtil;
import com.martico.service.search.ActivitySearchContext;

@Controller("activity")
@RequestMapping({ "view", "edit" })
public class ActivityController extends AbstractController {
	private static Log log = LogFactoryUtil.getLog(ActivityController.class);

	@RenderMapping(params = { "view=view-activity" })
	public ModelAndView viewActivity(@ModelAttribute("activityForm") ActivityForm form, ModelMap model, RenderRequest request, RenderResponse response) {
		log.trace("INIT--- viewActivity");
		long activityId = ParamUtil.getLong(request, "activityId");
		try {
			ServiceContext serviceContext = ServiceContextFactory.getInstance(request);
			PortletURL backURL = response.createRenderURL();
			backURL.setParameter("namespace", "activity");
			backURL.setParameter("view", "list-activity");		
			
			PortletURL editURL = response.createRenderURL();
			editURL.setParameter("namespace", "activity");
			editURL.setParameter("view", "edit-activity");
			editURL.setParameter("activityId", String.valueOf(activityId));
			model.put("editUrl", editURL);
			
			PortletURL deleteURL = response.createActionURL();
			deleteURL.setParameter(ActionRequest.ACTION_NAME, "delete-activity");
			deleteURL.setParameter("namespace", "activity");
			model.put("deleteUrl", deleteURL);
			
			ResourceURL printURL = response.createResourceURL();
			printURL.setResourceID("print-activity");
			printURL.setParameter("namespace", "activity");
			printURL.setParameter("activityId", String.valueOf(activityId));
			model.put("printUrl", printURL);
			
			Activity activity = ActivityLocalServiceUtil.getActivity(activityId);
			putSelectedCategoriesIntoModel(model, activity, serviceContext);
			model.put("activity", activity);
			model.put("backUrl", backURL);
			model.put("title", "activity.view");
		} catch (PortalException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (SystemException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return new ModelAndView("view", model);
	}
	
	@ResourceMapping(value = "print-activity")
	public void printActivity(ResourceRequest resourceRequest, ResourceResponse resourceResponse) throws Exception {
		Long activityId = ParamUtil.get(resourceRequest, "activityId", 0L);
		Activity activity = ActivityLocalServiceUtil.getActivity(activityId);
		ActivityPdfWriter pdfWriter = new ActivityPdfWriter(resourceRequest, resourceResponse, activity.getName() + ".pdf");
		pdfWriter.open();
		pdfWriter.write(activity);
		pdfWriter.close();
		log.info("FINISH---printActivity");
	}
	
	@ResourceMapping(value = "print-activities")
	public void exportIdeasToPdf(ResourceRequest resourceRequest, ResourceResponse resourceResponse) throws Exception {
		// IdeaExportHelper.exportIdeaPDF(resourceRequest, resourceResponse);
		String activityIds = ParamUtil.getString(resourceRequest, "activityIds");
		long[] activityIdArray = ArrayUtils.stringToLongArray(activityIds);
		ActivityPdfWriter pdfWriter = new ActivityPdfWriter(resourceRequest, resourceResponse, "activities.pdf");
		pdfWriter.open();
		for (long ideaId : activityIdArray) {
			Activity activity = ActivityLocalServiceUtil.getActivity(ideaId);
			pdfWriter.write(activity);
		}
		pdfWriter.close();
		log.info("FINISH---printActivities");
	}

	@ActionMapping("delete-activity")
	public void deleteActivity(ActionRequest request, ActionResponse response) {
		log.trace("START---deleteActivity");
		long activityId = ParamUtil.getLong(request, "activityId");
		try {
			ActivityLocalServiceUtil.deleteActivity(activityId);
			SessionMessages.add(request, "activity.delete.success");
			response.setRenderParameter("namespace", "activity");
			response.setRenderParameter("view", "view-project");
		} catch (PortalException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (SystemException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	@ActionMapping("edit-activity")
	public void editActivity(@ModelAttribute("activityForm") ActivityForm form, ModelMap model, ActionRequest request, ActionResponse response) {
		log.trace("START---editActivity");
		List<String> errors = new ArrayList<String>();
		Activity activity=null, createdActivity = null;
		try {
			ServiceContext serviceContext = ServiceContextFactory.getInstance(request);
			if (!ActivityValidator.validate(form, errors)) {
				for (String error : errors) {
					SessionErrors.add(request, error);
				}
			} else {
				activity = form.fillActivity();
				serviceContext.setAssetCategoryIds(form.extractAssetCategories());
				createdActivity = ActivityLocalServiceUtil.addActivity(activity, serviceContext);
			}
		} catch (SystemException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (PortalException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (ParseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		if (SessionErrors.isEmpty(request)) {
			SessionMessages.add(request, "activity.save.success");
			response.setRenderParameter("namespace", "activity");
			response.setRenderParameter("view", "view-activity");
			response.setRenderParameter("activityId", String.valueOf(createdActivity.getActivityId()));
			
		}
		else {
			response.setRenderParameter("namespace", "activity");
			response.setRenderParameter("view", "edit-activity");
		}
		log.trace("FINISH---editActivity");
	}
	
	
	@RenderMapping(params = { "view=edit-activity" })
	public ModelAndView editActivity(@ModelAttribute("activityForm") ActivityForm form, ModelMap model, RenderRequest request, RenderResponse response) {
		log.trace("INIT--- editActivity");
		long activityId = ParamUtil.getLong(request, "activityId");
		try {
			Activity activity = ActivityLocalServiceUtil.fetchActivity(activityId);
			ServiceContext serviceContext = ServiceContextFactory.getInstance(request);
			putCategoriesIntoModel(model, serviceContext);
			String title="activity.create";
			PortletURL backURL = response.createRenderURL();
			backURL.setParameter("namespace", "activity");
			long[] categoryIds = new long[0];
			if (form.getActivityDay()==null || form.getActivityMonth()==null || form.getActivityYear()==null) {
				Calendar calendar = Calendar.getInstance();
				calendar.setTime(new Date());
				form.setActivityDay(calendar.get(Calendar.DAY_OF_MONTH));
				form.setActivityMonth(calendar.get(Calendar.MONTH));
				form.setActivityYear(calendar.get(Calendar.YEAR));
			}
			if (activity!=null) {
				Map<String, AssetCategory> activityCategories = ActivityUtil.getActivityCategories(serviceContext, activity);
				form.fillForm(activity,activityCategories);
				categoryIds = form.extractAssetCategories();
				backURL.setParameter("view", "view-activity");
				backURL.setParameter("activityId", String.valueOf(activityId));
				title="activity.edit";
			} else {
				backURL.setParameter("view", "list-activity");		
			}
			model.put("assetCategoryIds", categoryIds);
			model.put("title", title);
			model.put("backUrl", backURL);
		} catch (SystemException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (PortalException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return new ModelAndView("edit", model);
	}
	
	@RenderMapping(params = { "view=list-activity" })
	public ModelAndView listActivity(ModelMap model, RenderRequest request, RenderResponse response) {
		log.trace("INIT--- listActivity");
		ServiceContext serviceContext;
		try {
			serviceContext = ServiceContextFactory.getInstance(request);
			ActivitySearchContainer searchContainer = buildSearchContainer(request, response);
			ActivitySearchDisplayTerms displayTerms = (ActivitySearchDisplayTerms) searchContainer.getSearchTerms();
			ActivitySearchContext searchContext = displayTerms.getSearchContext();
			List<Activity> searchResults = ActivityLocalServiceUtil.search(searchContext, serviceContext);
			searchContainer.fillSearchContainer(searchResults);
			// Model
			model.put("searchContainer", searchContainer);
			model.put("title", "activity.list");
			putCategoriesIntoModel(model, serviceContext);
			
			ResourceURL printURL = response.createResourceURL();
			printURL.setResourceID("print-activities");
			printURL.setParameter("namespace", "activity");
			model.put("printUrl", printURL);
		} catch (PortalException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (SystemException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return new ModelAndView("list", model);
	}
	
	@RenderMapping 
	public ModelAndView viewMain(RenderRequest request, RenderResponse response) {
		log.trace("view");
		ModelMap model = new ModelMap();
		return listActivity(model,request, response);
	}
	
	public static void putCategoriesIntoModel(ModelMap model, ServiceContext serviceContext) throws PortalException, SystemException {
		AssetVocabulary vocabulary = AssetVocabularyLocalServiceUtil.getGroupVocabulary(serviceContext.getScopeGroupId(), ActivityUtil.SECTION_VOCABULARY_NAME); 
		model.addAttribute("sectionCategories", getSortedCategories(vocabulary.getVocabularyId()));
		vocabulary = AssetVocabularyLocalServiceUtil.getGroupVocabulary(serviceContext.getScopeGroupId(), ActivityUtil.TYPE_VOCABULARY_NAME); 
		model.addAttribute("typeCategories", getSortedCategories(vocabulary.getVocabularyId()));
	}
	
	private static List<AssetCategory> getSortedCategories(long vocabularyId) throws SystemException {
		List<AssetCategory> categories = AssetCategoryLocalServiceUtil.getVocabularyCategories(vocabularyId, 0, QueryUtil.ALL_POS, null);
		categories = new ArrayList<AssetCategory>(categories);
		Collections.sort(categories, new AssetCategoryComparator());
		return categories;
	}
	
	private static ActivitySearchContainer buildSearchContainer(RenderRequest request, RenderResponse response) {

		PortletURL iteratorURL = response.createRenderURL();
		iteratorURL.setParameter("namespace", "activity");

		ActivitySearchContainer searchContainer = new ActivitySearchContainer(request, iteratorURL);
		ActivitySearchDisplayTerms displayTerms = (ActivitySearchDisplayTerms) searchContainer.getSearchTerms();
		iteratorURL.setParameter(ActivitySearchDisplayTerms.NAME, displayTerms.getName());
		iteratorURL.setParameter(ActivitySearchDisplayTerms.START_DAY, String.valueOf(displayTerms.getStartDay()));
		iteratorURL.setParameter(ActivitySearchDisplayTerms.START_MONTH, String.valueOf(displayTerms.getStartMonth()));
		iteratorURL.setParameter(ActivitySearchDisplayTerms.START_YEAR, String.valueOf(displayTerms.getStartYear()));
		iteratorURL.setParameter(ActivitySearchDisplayTerms.END_DAY, String.valueOf(displayTerms.getEndDay()));
		iteratorURL.setParameter(ActivitySearchDisplayTerms.END_MONTH, String.valueOf(displayTerms.getEndMonth()));
		iteratorURL.setParameter(ActivitySearchDisplayTerms.END_YEAR, String.valueOf(displayTerms.getEndYear()));
		iteratorURL.setParameter(ActivitySearchDisplayTerms.SECTION, String.valueOf(displayTerms.getSection()));
		iteratorURL.setParameter(ActivitySearchDisplayTerms.TYPE, String.valueOf(displayTerms.getType()));

		return searchContainer;
	}
	
	private void putSelectedCategoriesIntoModel(ModelMap model, Activity activity, ServiceContext serviceContext) throws PortalException, SystemException {
		Map<String, AssetCategory> categories = ActivityUtil.getActivityCategories(serviceContext, activity);
		model.put("typeCategory", categories.get("typeCategory").getName());
		model.put("sectionCategory", categories.get("sectionCategory").getName());
	}
}
