package com.martico.portlet.activity.export;

import java.io.IOException;
import java.text.DateFormat;
import java.util.Locale;

import javax.portlet.ResourceRequest;
import javax.portlet.ResourceResponse;

import org.apache.commons.lang.StringUtils;

import com.itextpdf.text.Chunk;
import com.itextpdf.text.DocumentException;
import com.itextpdf.text.Element;
import com.itextpdf.text.Paragraph;
import com.itextpdf.text.Rectangle;
import com.itextpdf.text.pdf.PdfPCell;
import com.itextpdf.text.pdf.PdfPTable;
import com.itextpdf.text.pdf.draw.LineSeparator;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.util.DateFormatFactoryUtil;
import com.martico.model.Activity;
import com.martico.portlet.activity.util.ActivityUtil;
import com.martico.portlet.util.AbstractPdfWriter;
import com.martico.portlet.util.DecimalFormatUtil;
import com.martico.portlet.util.ResourceBundleUtil;

public class ActivityPdfWriter extends AbstractPdfWriter<Activity> {

	public ActivityPdfWriter(ResourceRequest resourceRequest,
			ResourceResponse resourceResponse, String fileName)
			throws PortalException, SystemException, DocumentException,
			IOException {
		super(resourceRequest, resourceResponse, fileName);
	}

	public void write(Activity activity) throws Exception {
		Locale locale = themeDisplay.getLocale();
		if (!idList.isEmpty())
			document.add(Chunk.NEXTPAGE);
		DateFormat dateFormat = DateFormatFactoryUtil.getDate(locale);
		document.add(Chunk.NEWLINE);
		document.add(createTitle(ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.activitySheet.title"),Element.ALIGN_RIGHT));
		byte columns = 6;
		String[][] activityHeaderBlock= new String[3][columns];
		activityHeaderBlock[0][0] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.name", new Object[] {}) + ": ";
		activityHeaderBlock[0][1] = activity.getName();
		activityHeaderBlock[0][2] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.type", new Object[] {}) + ": ";
		activityHeaderBlock[0][3] = ActivityUtil.getTypeCategory(themeDisplay,
				activity);
		activityHeaderBlock[0][4] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.section", new Object[] {}) + ": ";
		activityHeaderBlock[0][5] = ActivityUtil.getSectionCategory(themeDisplay,
				activity);
		activityHeaderBlock[1][0] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.responsible", new Object[] {})
				+ ": ";
		activityHeaderBlock[1][1] = activity.getResponsible();
		activityHeaderBlock[1][2] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.date", new Object[] {}) + ": ";
		activityHeaderBlock[1][3] = dateFormat.format(activity.getDate());
		activityHeaderBlock[1][4] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.duration", new Object[] {}) + ": ";
		activityHeaderBlock[1][5] = String.valueOf(activity.getDuration());
		activityHeaderBlock[2][0] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.recipient", new Object[] {}) + ": ";
		activityHeaderBlock[2][1] = String.valueOf(activity.getRecipient());
		activityHeaderBlock[2][2] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.ages", new Object[] {}) + ": ";
		activityHeaderBlock[2][3] = activity.getAges();
		activityHeaderBlock[2][4] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.place", new Object[] {}) + ": ";
		activityHeaderBlock[2][5] = activity.getPlace();

		createActivityTable(columns, activityHeaderBlock, locale);

		columns = 2;
		String[][] activityObjectivesBudgetBlock = new String[3][columns];
		activityObjectivesBudgetBlock[0][0] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.objectives", new Object[] {}) + ": ";
		activityObjectivesBudgetBlock[0][1] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.budget.title", new Object[] {})
				+ ": ";
		activityObjectivesBudgetBlock[1][0] = activity.getObjective();
		activityObjectivesBudgetBlock[1][1] = activity.getEquipmentToBuy();
		activityObjectivesBudgetBlock[2][0] = StringUtils.EMPTY;
		activityObjectivesBudgetBlock[2][1] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.budget", new Object[] {})
				+ ": "
				+ DecimalFormatUtil.getCurrencyFormat(activity.getBudget());

		createActivityTable(columns, activityObjectivesBudgetBlock, locale);
		
		createSingleActivityTable(ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.description", new Object[] {})
				+ ": ", activity.getDescription());
		
		String[][] activityPersonalMaterialBlock = new String[2][columns];
		activityPersonalMaterialBlock[0][0] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.personal", new Object[] {}) + ": ";
		activityPersonalMaterialBlock[0][1] = ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.material", new Object[] {})
				+ ": ";
		activityPersonalMaterialBlock[1][0] = activity.getPersonal();
		activityPersonalMaterialBlock[1][1] = activity.getMaterial();
		createActivityTable(columns, activityPersonalMaterialBlock, locale);

		createSingleActivityTable(ResourceBundleUtil.getString(locale,
				"activitySheet", "activity.observation", new Object[] {})
				+ ": ", activity.getObservation());
		
		document.add(new Chunk(new LineSeparator()));
		
		idList.add(activity.getActivityId());
	}

	private void createSingleActivityTable(String title, String content) throws DocumentException {
		PdfPTable table = createPDFTable(1);
		table.addCell(addTitleCell(title,Element.ALIGN_LEFT,true));
		table.addCell(addNormalCell(content,Element.ALIGN_LEFT,true));
		document.add(table);
	}
	
	protected void addHoritzontalLine() {
		PdfPTable table = createPDFTable(1);
		PdfPCell myCell = new PdfPCell(new Paragraph(StringUtils.EMPTY) );
		myCell.setBorder(Rectangle.BOTTOM);
		try {
			document.add(table);
		} catch (DocumentException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	private void createActivityTable(byte columns, String[][] activityTable,
			Locale locale) throws PortalException, SystemException,
			DocumentException {
		PdfPTable pdfTable = createPDFTable(columns);
		for (int i = 0; i < activityTable.length; i++) {
			if (columns > 2) {
				pdfTable = createPDFTable(columns);
			}
			for (int j = 0; j < activityTable[i].length; j++) {
				if (columns > 2) {
					if (j % 2 == 0) {
						pdfTable.addCell(addTitleCell(activityTable[i][j],
								Element.ALIGN_LEFT,false));
					} else {
						pdfTable.addCell(addNormalCell(activityTable[i][j],
								Element.ALIGN_LEFT,false));
					}
					document.add(pdfTable);
				} else {
					if (i == 0) {
						pdfTable.addCell(addTitleCell(activityTable[i][j],
								Element.ALIGN_LEFT,false));
					} else {
						pdfTable.addCell(addNormalCell(activityTable[i][j],
								Element.ALIGN_LEFT,false));
					}
				}
			}
		}
		if (columns <= 2) {
			document.add(pdfTable);
		}
	}
}
