package com.martico.portlet.activity.form;

import java.io.Serializable;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Date;
import java.util.Map;

import com.liferay.portal.kernel.util.Validator;
import com.liferay.portlet.asset.model.AssetCategory;
import com.martico.model.Activity;
import com.martico.model.impl.ActivityImpl;
import com.martico.portlet.util.DateUtil;
import com.martico.portlet.util.DecimalFormatUtil;

public class ActivityForm implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = -686766671441452299L;
	Long activityId;
	String name;
	String responsible;
	private Integer activityDay;

	private Integer activityMonth;

	private Integer activityYear;

	String duration;
	String recipient;
	String ages;
	String equipmentToBuy;
	String budget;
	String place;
	
	String objectives;
	String description;
	String personal;
	String material; 
	String observation;
	
	String sectionCategory;
	String typeCategory;
	
	public Long getActivityId() {
		return activityId;
	}
	public void setActivityId(Long activityId) {
		this.activityId = activityId;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getResponsible() {
		return responsible;
	}
	public void setResponsible(String responsible) {
		this.responsible = responsible;
	}
	
	public Integer getActivityDay() {
		return activityDay;
	}
	public void setActivityDay(Integer activityDay) {
		this.activityDay = activityDay;
	}
	public Integer getActivityMonth() {
		return activityMonth;
	}
	public void setActivityMonth(Integer activityMonth) {
		this.activityMonth = activityMonth;
	}
	public Integer getActivityYear() {
		return activityYear;
	}
	public void setActivityYear(Integer activityYear) {
		this.activityYear = activityYear;
	}
	public String getDuration() {
		return duration;
	}
	public void setDuration(String duration) {
		this.duration = duration;
	}
	public String getRecipient() {
		return recipient;
	}
	public void setRecipient(String recipient) {
		this.recipient = recipient;
	}
	public String getAges() {
		return ages;
	}
	public void setAges(String ages) {
		this.ages = ages;
	}
	public String getEquipmentToBuy() {
		return equipmentToBuy;
	}
	public void setEquipmentToBuy(String equipmentToBuy) {
		this.equipmentToBuy = equipmentToBuy;
	}
	public String getObservation() {
		return observation;
	}
	public void setObservation(String observation) {
		this.observation = observation;
	}
	
	public void fillForm(Activity activity,Map<String, AssetCategory> activityCategories) {
		setActivityId(activity.getActivityId());
		setName(activity.getName());
		setResponsible(activity.getResponsible());
		setDate(activity.getDate());
		setDuration(String.valueOf(activity.getDuration()));
		setRecipient(String.valueOf(activity.getRecipient()));
		setAges(activity.getAges());
		setPlace(activity.getPlace());
		setObjectives(activity.getObjective());
		setEquipmentToBuy(activity.getEquipmentToBuy());
		setBudget(DecimalFormatUtil.getCurrencyFormat(activity.getBudget()));
		setDescription(activity.getDescription());
		setPersonal(activity.getPersonal());
		setMaterial(activity.getMaterial());
		setObservation(activity.getObservation());
		AssetCategory sectionCategory2 = activityCategories.get("sectionCategory");
		setSectionCategory(sectionCategory2!=null?String.valueOf(sectionCategory2.getCategoryId()):"");
		AssetCategory typeCategory2 = activityCategories.get("typeCategory");
		setTypeCategory(typeCategory2!=null?String.valueOf(typeCategory2.getCategoryId()):"");
	}
	
	public Activity fillActivity() throws ParseException {
		Activity activity = new ActivityImpl();
		if(getActivityId()!=null) {
			activity.setActivityId(getActivityId());			
		}
		activity.setName(getName());
		activity.setResponsible(getResponsible());
		activity.setDate(DateUtil.buildDate(getActivityDay(),getActivityMonth(),getActivityYear()));
		activity.setDuration(Integer.parseInt(getDuration()));
		activity.setRecipient(Integer.parseInt(getRecipient()));
		activity.setAges(getAges());
		activity.setPlace(getPlace());
		activity.setObjective(getObjectives());
		activity.setEquipmentToBuy(getEquipmentToBuy());
		activity.setBudget(DecimalFormatUtil.getCurrencyFloat(getBudget()));
		activity.setDescription(getDescription());
		activity.setPersonal(getPersonal());
		activity.setMaterial(getMaterial());
		activity.setObservation(getObservation());
		return activity;
	}
	
	public long[] extractAssetCategories() {
		ArrayList<String> assetCategoryIdList = new ArrayList<String>();
		if (Validator.isNumber(getSectionCategory())) {
			assetCategoryIdList.add(getSectionCategory());
		}
		if (Validator.isNumber(getTypeCategory())) {
			assetCategoryIdList.add(getTypeCategory());
		}
		
		long[] assetCategoryIds = new long[assetCategoryIdList.size()];
		for (int i = 0; i < assetCategoryIds.length; i++) {
			String string = assetCategoryIdList.get(i);
			assetCategoryIds[i]=Long.valueOf(string);
		}
		Arrays.sort(assetCategoryIds);
		return assetCategoryIds;
	}
	
	public void setDate(Date date) {
		if (date != null) {
			Calendar calendar = Calendar.getInstance();
			calendar.setTime(date);
			setActivityDay(calendar.get(Calendar.DAY_OF_MONTH));
			setActivityMonth(calendar.get(Calendar.MONTH));
			setActivityYear(calendar.get(Calendar.YEAR));
		} else {
			setActivityDay(null);
			setActivityMonth(null);
			setActivityYear(null);
		}
	}
	public String getBudget() {
		return budget;
	}
	public String getPlace() {
		return place;
	}
	public String getObjectives() {
		return objectives;
	}
	
	public String getPersonal() {
		return personal;
	}
	public String getMaterial() {
		return material;
	}
	public void setBudget(String budget) {
		this.budget = budget;
	}
	public void setPlace(String place) {
		this.place = place;
	}
	public void setObjectives(String objectives) {
		this.objectives = objectives;
	}
	public void setPersonal(String personal) {
		this.personal = personal;
	}
	public void setMaterial(String material) {
		this.material = material;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public String getSectionCategory() {
		return sectionCategory;
	}
	public void setSectionCategory(String sectionCategory) {
		this.sectionCategory = sectionCategory;
	}
	public String getTypeCategory() {
		return typeCategory;
	}
	public void setTypeCategory(String typeCategory) {
		this.typeCategory = typeCategory;
	}
}
