package com.martico.portlet.activity.search;

import java.util.Calendar;
import java.util.Date;

import javax.portlet.PortletRequest;

import com.liferay.portal.kernel.dao.search.DisplayTerms;
import com.liferay.portal.kernel.util.ParamUtil;
import com.martico.portlet.util.DateUtil;
import com.martico.service.search.ActivitySearchContext;


public class ActivitySearchDisplayTerms extends DisplayTerms {

	
	public static final String NAME = "name";
	public static final String START_DATE = "startDate";
	public static final String START_DAY = "startDay";
	public static final String START_MONTH = "startMonth";
	public static final String START_YEAR = "startYear";

	public static final String END_DATE = "endDate";
	public static final String END_DAY = "endDay";
	public static final String END_MONTH = "endMonth";
	public static final String END_YEAR = "endYear";
	public static final String TYPE = "typeCategory";
	public static final String SECTION = "sectionCategory";

	private String name;
	
	private Integer startDay;
	private Integer startMonth;
	private Integer startYear;
	
	private Integer endDay;
	private Integer endMonth;
	private Integer endYear;
	
	//CATEGORIES
	private long type;
	private long section;
	
	public ActivitySearchDisplayTerms(PortletRequest portletRequest) {
		super(portletRequest);
		// ThemeDisplay themeDisplay = (ThemeDisplay) portletRequest
		// .getAttribute(WebKeys.THEME_DISPLAY);
		name = ParamUtil.getString(portletRequest, NAME);
		Calendar calendar = Calendar.getInstance();
		calendar.setTime(new Date());
		startDay = ParamUtil.getInteger(portletRequest, START_DAY,calendar.get(Calendar.DAY_OF_MONTH));
		startMonth = ParamUtil.getInteger(portletRequest, START_MONTH,calendar.get(Calendar.MONTH));
		startYear = ParamUtil.getInteger(portletRequest, START_YEAR,calendar.get(Calendar.YEAR));
		
		endDay = ParamUtil.getInteger(portletRequest, END_DAY,calendar.get(Calendar.DAY_OF_MONTH));
		endMonth = ParamUtil.getInteger(portletRequest, END_MONTH,calendar.get(Calendar.MONTH));
		endYear = ParamUtil.getInteger(portletRequest, END_YEAR,calendar.get(Calendar.YEAR));
		
		
		//CATEGORIES
		type = ParamUtil.getLong(portletRequest, TYPE);
		section = ParamUtil.getLong(portletRequest, SECTION);

	}
	
	public ActivitySearchContext getSearchContext(){
		long[] categoryIds = ActivitySearchContext.buildCategoryIds(getSection(), getType());
		ActivitySearchContext result =  new ActivitySearchContext(getName(),
				DateUtil.buildDate(getStartDay(), getStartMonth(), getStartYear()), DateUtil.buildDate(getEndDay(), getEndMonth(), getEndYear()), getKeywords(),
				categoryIds,
				isAndOperator());
		
		return result;
	}

	public String getName() {
		return name;
	}

	public Integer getStartDay() {
		return startDay;
	}

	public Integer getStartMonth() {
		return startMonth;
	}

	public Integer getStartYear() {
		return startYear;
	}

	public Integer getEndDay() {
		return endDay;
	}

	public Integer getEndMonth() {
		return endMonth;
	}

	public Integer getEndYear() {
		return endYear;
	}

	public long getType() {
		return type;
	}

	public long getSection() {
		return section;
	}

	public void setName(String name) {
		this.name = name;
	}

	public void setStartDay(Integer startDay) {
		this.startDay = startDay;
	}

	public void setStartMonth(Integer startMonth) {
		this.startMonth = startMonth;
	}

	public void setStartYear(Integer startYear) {
		this.startYear = startYear;
	}

	public void setEndDay(Integer endDay) {
		this.endDay = endDay;
	}

	public void setEndMonth(Integer endMonth) {
		this.endMonth = endMonth;
	}

	public void setEndYear(Integer endYear) {
		this.endYear = endYear;
	}

	public void setType(long type) {
		this.type = type;
	}

	public void setSection(long section) {
		this.section = section;
	}

	
}
