package com.martico.portlet.activity.util;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.service.ServiceContext;
import com.liferay.portal.theme.ThemeDisplay;
import com.liferay.portlet.asset.model.AssetCategory;
import com.liferay.portlet.asset.model.AssetVocabulary;
import com.liferay.portlet.asset.service.AssetCategoryLocalServiceUtil;
import com.liferay.portlet.asset.service.AssetVocabularyLocalServiceUtil;
import com.martico.model.Activity;

public class ActivityUtil {
	public static final String TYPE_VOCABULARY_NAME = "Tipus d'Activitat";
	public static final String SECTION_VOCABULARY_NAME = "Seccions";

	public static Map<String, AssetCategory> getActivityCategories(ServiceContext serviceContext, Activity activity) throws PortalException, SystemException {

		Map<String, AssetCategory> categories = new HashMap<String, AssetCategory>();
		AssetCategory sectionCategory = getSectionCategory(serviceContext, activity);
		categories.put("sectionCategory", sectionCategory);
		AssetCategory typeCategory = getTypeCategory(serviceContext, activity);
		categories.put("typeCategory", typeCategory);
		return categories;
	}
	
	public static AssetCategory getSectionCategory(ServiceContext serviceContext, Activity activity) throws PortalException, SystemException {
		AssetCategory section=null;
		AssetVocabulary sectionVocabulary = AssetVocabularyLocalServiceUtil.getGroupVocabulary(serviceContext.getScopeGroupId(), SECTION_VOCABULARY_NAME); 
		List<AssetCategory> assetCategory = AssetCategoryLocalServiceUtil.getCategories(Activity.class.getName(), activity.getActivityId());
		for (AssetCategory category : assetCategory) {
			if (sectionVocabulary.getVocabularyId() == category.getVocabularyId()) {
				section=category;
			}
		}
		return section;
	}
	
	public static AssetCategory getTypeCategory(ServiceContext serviceContext, Activity activity) throws PortalException, SystemException {
		AssetCategory type=null;
		AssetVocabulary sectionVocabulary = AssetVocabularyLocalServiceUtil.getGroupVocabulary(serviceContext.getScopeGroupId(), TYPE_VOCABULARY_NAME); 
		List<AssetCategory> assetCategory = AssetCategoryLocalServiceUtil.getCategories(Activity.class.getName(), activity.getActivityId());
		for (AssetCategory category : assetCategory) {
			if (sectionVocabulary.getVocabularyId() == category.getVocabularyId()) {
				type=category;
			}
		}
		return type;
	}
	
	public static String getSectionCategory(ThemeDisplay themeDisplay, Activity activity) throws PortalException, SystemException {
		String section="";
		AssetVocabulary sectionVocabulary = AssetVocabularyLocalServiceUtil.getGroupVocabulary(themeDisplay.getScopeGroupId(), SECTION_VOCABULARY_NAME); 
		List<AssetCategory> assetCategory = AssetCategoryLocalServiceUtil.getCategories(Activity.class.getName(), activity.getActivityId());
		for (AssetCategory category : assetCategory) {
			if (sectionVocabulary.getVocabularyId() == category.getVocabularyId()) {
				section=category.getName();
			}
		}
		return section;
	}
	
	public static String getTypeCategory(ThemeDisplay themeDisplay, Activity activity) throws PortalException, SystemException {
		String section="";
		AssetVocabulary sectionVocabulary = AssetVocabularyLocalServiceUtil.getGroupVocabulary(themeDisplay.getScopeGroupId(), TYPE_VOCABULARY_NAME); 
		List<AssetCategory> assetCategory = AssetCategoryLocalServiceUtil.getCategories(Activity.class.getName(), activity.getActivityId());
		for (AssetCategory category : assetCategory) {
			if (sectionVocabulary.getVocabularyId() == category.getVocabularyId()) {
				section=category.getName();
			}
		}
		return section;
	}
}
