package com.martico.portlet.bookmark;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletPreferences;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.portlet.ModelAndView;
import org.springframework.web.portlet.bind.annotation.ActionMapping;
import org.springframework.web.portlet.bind.annotation.RenderMapping;
import org.springframework.web.portlet.mvc.AbstractController;

import com.liferay.portal.kernel.dao.orm.QueryUtil;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.service.ServiceContext;
import com.liferay.portal.service.ServiceContextFactory;
import com.liferay.portlet.bookmarks.model.BookmarksEntry;
import com.liferay.portlet.bookmarks.model.BookmarksFolderConstants;
import com.liferay.portlet.bookmarks.service.BookmarksEntryLocalServiceUtil;
import com.martico.portlet.bookmark.util.BookmarkComparator;

@Controller("bookmark")
@RequestMapping({ "view", "edit" })
public class BookmarkController extends AbstractController {
	private static Log log = LogFactoryUtil.getLog(BookmarkController.class);

	@RenderMapping
	public ModelAndView viewMain(ModelMap model, RenderRequest request, RenderResponse response) {
		log.trace("INIT--- viewMain");
		ServiceContext serviceContext;
		try {
			serviceContext = ServiceContextFactory.getInstance(request);
			PortletPreferences preferences = request.getPreferences();
			String strFolderId = preferences.getValue("folderId",String.valueOf(BookmarksFolderConstants.DEFAULT_PARENT_FOLDER_ID));
			Long folderId = Long.parseLong(strFolderId);
			List<BookmarksEntry> bookmarks = BookmarksEntryLocalServiceUtil.getEntries(serviceContext.getScopeGroupId(), folderId, QueryUtil.ALL_POS, QueryUtil.ALL_POS);
			List<BookmarksEntry> bookmarkEntries = new ArrayList<BookmarksEntry>(bookmarks);
			Collections.sort(bookmarkEntries, new BookmarkComparator());
			model.put("bookmarks", bookmarkEntries);
		} catch (PortalException e) {
			log.trace(e);
		} catch (SystemException e) {
			// TODO Auto-generated catch block
			log.trace(e);
		}
		return new ModelAndView("view", model);
	}
	
	@ActionMapping("redirect")
	public void redirect(ActionRequest request, ActionResponse response) {
		long bookmarkId = ParamUtil.getLong(request, "bookmarkId");
		try {
			BookmarksEntry bookmark = BookmarksEntryLocalServiceUtil.getBookmarksEntry(bookmarkId);
			bookmark.setVisits(bookmark.getVisits()+1);
			BookmarksEntryLocalServiceUtil.updateBookmarksEntry(bookmark);
			response.sendRedirect(bookmark.getUrl());
		} catch (PortalException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (SystemException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
