package com.martico.search;

import com.martico.search.comparator.OrderByComparatorFactory;
import com.liferay.portal.kernel.dao.search.DisplayTerms;
import com.liferay.portal.kernel.dao.search.SearchContainer;
import com.liferay.portal.kernel.util.ListUtil;
import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.portal.kernel.util.ParamUtil;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import javax.portlet.PortletURL;
import javax.portlet.RenderRequest;

public class DefaultSearchContainer<T> extends SearchContainer<T>{
	private static final int DEFAULT_DELTA = 10;
	private static final String ORDER_BY_TYPE = "orderByType";
	private static final String ORDER_BY_COL = "orderByCol";
	private static final String CURRENT_PAGE = "cur";
	private static final String DELTA = "delta";
	

	public DefaultSearchContainer(RenderRequest request, PortletURL iteratorURL, DisplayTerms display) {
		super(request, null, display, SearchContainer.DEFAULT_CUR_PARAM, ParamUtil.getInteger(request, CURRENT_PAGE, 1), ParamUtil
				.getInteger(request, DELTA, DEFAULT_DELTA), iteratorURL, null, "message.noResultsFound");
		String orderByCol = ParamUtil.getString(request, ORDER_BY_COL);
		String orderByType = ParamUtil.getString(request, ORDER_BY_TYPE);
		setOrderByCol(orderByCol);
		setOrderByType(orderByType);
		setOrderByComparator(buildOrderByComparator());
	}
	
	public DefaultSearchContainer(RenderRequest request, PortletURL iteratorURL, DisplayTerms display, String orderByColParam, String orderByTypeParam) {
		this(request,iteratorURL,display,SearchContainer.DEFAULT_CUR_PARAM,orderByColParam,orderByTypeParam);
	}
	
	public DefaultSearchContainer(RenderRequest request, PortletURL iteratorURL, DisplayTerms display, String curParam,String orderByColParam, String orderByTypeParam) {
		super(request, null, display, curParam, ParamUtil.getInteger(request, curParam, 1), ParamUtil
				.getInteger(request, DELTA, DEFAULT_DELTA), iteratorURL, null, "message.noResultsFound");
		this.setOrderByColParam(orderByColParam);
		this.setOrderByTypeParam(orderByTypeParam);
		String orderByCol = ParamUtil.getString(request, orderByColParam);
		String orderByType = ParamUtil.getString(request, orderByTypeParam);
		setOrderByCol(orderByCol);
		setOrderByType(orderByType);
		setOrderByComparator(buildOrderByComparator());
		
	}

	
	public void fillSearchContainer(List<? extends T> list) {
		if (list != null) {
			List<T> dest = sortResults(list);
			
			List<T> subList = ListUtil.subList(dest, getStart(), getEnd());
			setResults(subList);
			setTotal(list.size());
		}
	}

	public List<T> sortResults(List<? extends T> list) {
		List<T> dest = new ArrayList<T>(list.size());
		dest.addAll(list);
		OrderByComparator orderByComparator = getOrderByComparator();
		if (orderByComparator!=null) {
			Collections.sort(dest, orderByComparator);
		}
		return dest;
	}

	private OrderByComparator buildOrderByComparator() {
		OrderByComparator orderByComparator = null;
		if (!getOrderByCol().equals("")) {
			if (getOrderByType().equals("")) {
				setOrderByType(OrderByComparatorFactory.ASCENDING_ORDER_TYPE);
			}
			orderByComparator =  OrderByComparatorFactory.getOrderByComparator(getOrderByCol(), getOrderByType());
		}
		return orderByComparator;
	}

	
	
}
