package com.martico.search.comparator;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.util.PropertyComparator;

import java.lang.reflect.InvocationTargetException;

import org.apache.commons.beanutils.PropertyUtils;

public class PropertyOrderByComparator extends OrderByComparator {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private static Log _log = LogFactoryUtil.getLog(PropertyOrderByComparator.class);

	public class CustomPropertyComparator extends PropertyComparator {

		public CustomPropertyComparator(String propertyName, boolean ascending) {
			super(propertyName, ascending, true);
		}

		public int compare(Object obj1, Object obj2) {
			try {
				Object property1 = PropertyUtils.getProperty(obj1, getPropertyName());
				Object property2 = PropertyUtils.getProperty(obj2, getPropertyName());

				if (!isAscending()) {
					Object temp = property1;

					property1 = property2;
					property2 = temp;
				}

				if (property1 instanceof String) {
					int result = 0;

					result = property1.toString().compareTo(property2.toString());

					if (result != 0) {
						return result;
					}
				}
				if (property1 != null&&property2 != null) {
					if (property1 instanceof Comparable<?>) {
						int result = ((Comparable<Object>) property1).compareTo(property2);

						if (result != 0) {
							return result;
						}
					}
				}
				else if(property1 == null&&property2 != null)return -1;
				else if(property1 != null&&property2 == null)return 1;
				else return 0;
			}
			catch (IllegalAccessException iae) {
				_log.error(iae.getMessage());
			}
			catch (InvocationTargetException ite) {
				_log.error(ite.getMessage());
			}
			catch (NoSuchMethodException nsme) {
				_log.error(nsme.getMessage());
			}

			return -1;
		}

	}

	protected boolean ascending;
	protected String propertyName;
	private PropertyComparator comparator;

	public PropertyOrderByComparator(String propertyName) {
		this(propertyName, false);
	}

	public PropertyOrderByComparator(String propertyName, boolean ascending) {
		super();
		this.ascending = ascending;
		this.propertyName = propertyName;
		this.comparator = new CustomPropertyComparator(propertyName, ascending);
	}

	public boolean isAscending() {
		return ascending;
	}

	public String getPropertyName() {
		return propertyName;
	}

	@Override
	public int compare(Object obj1, Object obj2) {
		return comparator.compare(obj1, obj2);
	}

	@Override
	public String[] getOrderByFields() {
		return new String[] { propertyName };
	}

}
