/**
 * Copyright (c) 2000-2012 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.martico.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.liferay.portal.kernel.dao.orm.Criterion;
import com.liferay.portal.kernel.dao.orm.DynamicQuery;
import com.liferay.portal.kernel.dao.orm.DynamicQueryFactoryUtil;
import com.liferay.portal.kernel.dao.orm.Junction;
import com.liferay.portal.kernel.dao.orm.RestrictionsFactoryUtil;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.search.SearchContext;
import com.liferay.portal.service.ResourceLocalServiceUtil;
import com.liferay.portal.service.ServiceContext;
import com.liferay.portlet.asset.model.AssetEntry;
import com.liferay.portlet.asset.service.AssetEntryLocalServiceUtil;
import com.liferay.portlet.asset.service.persistence.AssetEntryQuery;
import com.martico.model.Activity;
import com.martico.service.base.ActivityLocalServiceBaseImpl;
import com.martico.service.search.ActivitySearchContext;

/**
 * The implementation of the activity local service.
 *
 * <p>
 * All custom service methods should be put in this class. Whenever methods are added, rerun ServiceBuilder to copy their definitions into the {@link com.martico.service.ActivityLocalService} interface.
 *
 * <p>
 * This is a local service. Methods of this service will not have security checks based on the propagated JAAS credentials because this service can only be accessed from within the same VM.
 * </p>
 *
 * @author edusaldana
 * @see com.martico.service.base.ActivityLocalServiceBaseImpl
 * @see com.martico.service.ActivityLocalServiceUtil
 */
public class ActivityLocalServiceImpl extends ActivityLocalServiceBaseImpl {
	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never reference this interface directly. Always use {@link com.martico.service.ActivityLocalServiceUtil} to access the activity local service.
	 */
	
	private static Log log = LogFactoryUtil.getLog(ActivityLocalServiceImpl.class);
	
	public Activity fetchActivity(long activityId) throws SystemException {
		return activityPersistence.fetchByPrimaryKey(activityId);
	}
	
	public Activity addActivity(Activity activity, ServiceContext serviceContext) throws SystemException, PortalException {
		Activity createdActivity = activityPersistence.fetchByPrimaryKey(activity.getActivityId());
		if (createdActivity==null) {
			//Nova activitat
			long activityId = counterLocalService.increment(Activity.class.getName());
			createdActivity = super.createActivity(activityId);
			createdActivity.setGroupId(serviceContext.getScopeGroupId());
			createdActivity.setCompanyId(serviceContext.getCompanyId());	
			createdActivity.setUserId(serviceContext.getUserId());
			addActivity(createdActivity);
			ResourceLocalServiceUtil.addResources(serviceContext.getCompanyId(), serviceContext.getScopeGroupId(), serviceContext.getUserId(),
						Activity.class.getName(), createdActivity.getActivityId(), false, true, true);
			
		} 
		createdActivity.setName(activity.getName());
		createdActivity.setResponsible(activity.getResponsible());
		createdActivity.setDate(activity.getDate());
		createdActivity.setDuration(activity.getDuration());
		createdActivity.setRecipient(activity.getRecipient());
		createdActivity.setAges(activity.getAges());
		createdActivity.setPlace(activity.getPlace());
		createdActivity.setObjective(activity.getObjective());
		createdActivity.setEquipmentToBuy(activity.getEquipmentToBuy());
		createdActivity.setBudget(activity.getBudget());
		createdActivity.setDescription(activity.getDescription());
		createdActivity.setPersonal(activity.getPersonal());
		createdActivity.setMaterial(activity.getMaterial());
		createdActivity.setObservation(activity.getObservation());
		assetEntryLocalService.updateEntry(serviceContext.getUserId(), serviceContext.getScopeGroupId(), Activity.class.getName(), createdActivity.getActivityId(),
				serviceContext.getAssetCategoryIds(), serviceContext.getAssetTagNames());
		updateActivity(createdActivity);
		return createdActivity;
	}
	
	public List<Activity> search(SearchContext searchContext, ServiceContext serviceContext) throws PortalException, SystemException, Exception {
		List<Activity> result = new ArrayList<Activity>();
		ActivitySearchContext activitySearchContext = (ActivitySearchContext) searchContext;
		try {
			long[] activitySubset = activitySearchContext.getActivityIds();

			DynamicQuery dynamicQuery = DynamicQueryFactoryUtil.forClass(Activity.class, getClass().getClassLoader());
			Criterion criterion = null;
			if (activitySearchContext.getKeywords().isEmpty()) {
				// Cerca avançada

				Junction junction = null;
				if (activitySearchContext.isAndSearch()) {
					junction = RestrictionsFactoryUtil.conjunction();
				}
				else {
					junction = RestrictionsFactoryUtil.disjunction();
				}
				if (!activitySearchContext.getName().isEmpty()) {
					junction.add(RestrictionsFactoryUtil.ilike("name", "%" + activitySearchContext.getName() + "%"));
				}

				junction.add(RestrictionsFactoryUtil.between("date", activitySearchContext.getStartDate(), activitySearchContext.getEndDate()));

				if (activitySearchContext.getCategoryIds() != null && activitySearchContext.getCategoryIds().length > 0) {
					List<Object> assetEntry = new ArrayList<Object>();
					AssetEntryQuery assetEntryQuery = new AssetEntryQuery();
					if (activitySearchContext.isAndSearch()) {
						assetEntryQuery.setAllCategoryIds(searchContext.getCategoryIds());
					}
					else {
						assetEntryQuery.setAnyCategoryIds(searchContext.getCategoryIds());
					}

					List<AssetEntry> assetEntryList = AssetEntryLocalServiceUtil.getEntries(assetEntryQuery);
					for (AssetEntry ae : assetEntryList) {
						assetEntry.add(ae.getClassPK());
					}
					if (assetEntry.isEmpty()) {
						if (activitySearchContext.isAndSearch()) {
							return new ArrayList<Activity>();
						}
					}
					else {
						junction.add(RestrictionsFactoryUtil.in("activityId", assetEntry));
					}
				}
				// Entidades relacionadas

				criterion = junction;
			}
			else {
				// Cerca simple

				Junction junction = RestrictionsFactoryUtil.disjunction();
				junction = junction.add(RestrictionsFactoryUtil.ilike("name", "%" + searchContext.getKeywords() + "%"));
				criterion = junction;
			}
			Junction conjunction = RestrictionsFactoryUtil.conjunction();
			conjunction = conjunction.add(criterion);
			conjunction = conjunction.add(RestrictionsFactoryUtil.eq("companyId", serviceContext.getCompanyId()));
			conjunction = conjunction.add(RestrictionsFactoryUtil.eq("groupId", serviceContext.getScopeGroupId()));

			// Limitamos el subconjunto sobre el que buscamos
			if (activitySubset != null) {
				if (activitySubset.length == 0) {
					return new ArrayList<Activity>();
				}
				List<Object> activityIdList = new ArrayList<Object>();
				for (int i = 0; i < activitySubset.length; i++) {
					long l = activitySubset[i];
					activityIdList.add(l);
				}
				conjunction = conjunction.add(RestrictionsFactoryUtil.in("activityId", activityIdList));
			}
			
			dynamicQuery = dynamicQuery.add(conjunction);
			result = dynamicQuery(dynamicQuery);
		}
		catch (SystemException e) {
			log.error("", e);
		}
		return result;
	}
}